/* --------------------------------------------------------------- */
/* tollosBit.h -- bit (digitial pin) functions for Tollos          */
/* --------------------------------------------------------------- */
/*                                                                 */
/* Copyright (c) Mike Cowlishaw, 2010-2011.  All rights reserved.  */
/*                                                                 */
/* Permission to use, copy, modify, and/or distribute this         */
/* software for any purpose with or without fee is hereby granted, */
/* provided that the above copyright notice and this permission    */
/* notice appear in all copies, and that notice and the date of    */
/* any modifications be added to the software.                     */
/*                                                                 */
/* This software is provided "as is".  No warranties, whether      */
/* express, implied, or statutory, including, but not limited to,  */
/* implied warranties of merchantability and fitness for a         */
/* particular purpose apply to this software.  The author shall    */
/* not, in any circumstances, be liable for special, incidental,   */
/* or consequential damages, for any reason whatsoever.            */
/*                                                                 */
/* --------------------------------------------------------------- */
/* Generic control functions for the digital I/O pins of a device  */
/* (also called Ports or GPIO registers).                          */
/* --------------------------------------------------------------- */
// Assumes up to 32 bits per port


#ifndef TOLLOS_BIT_USED
#define TOLLOS_BIT_USED

#include "tollos.h"      // types etc.

/* Constants */

// Bit output actions
#define BIT_OUTPUT      0x10  // 1 for an output action, 0 for an input
#define BIT_OFF         0x11  // set to output mode and set bit(s) off
#define BIT_ON          0x12  // ditto, and set bit(s) on
#define BIT_INVERT      0x13  // ditto, and invert bit(s)
#define BIT_OPENDRAIN   0x14  // set to open drain and level high

// Bit input actions
#define BIT_TRISTATE    0x01  // set to input mode, tri-state
#define BIT_PULLUP      0x02  // ditto, pullup
#define BIT_PULLDOWN    0x03  // ditto, pulldown

// Bit interrupt modes
#define BIT_DISABLE        0  // disable interrupt
#define BIT_FALL           1  // interrupt on falling edge
#define BIT_RISE           2  // interrupt on rising edge
#define BIT_RISEFALL       3  // interrupt on both rising and falling edge
                              // may need levels later

// BITnn are bit masks, as opposed to pin numbers (PINnn)
#define BIT0   (1<< 0)        // 0x00000001
#define BIT1   (1<< 1)        // 0x00000002
#define BIT2   (1<< 2)        // 0x00000004
#define BIT3   (1<< 3)        // .. etc.
#define BIT4   (1<< 4)
#define BIT5   (1<< 5)
#define BIT6   (1<< 6)
#define BIT7   (1<< 7)
#define BIT8   (1<< 8)
#define BIT9   (1<< 9)
#define BIT10  (1<<10)
#define BIT11  (1<<11)
#define BIT12  (1<<12)
#define BIT13  (1<<13)
#define BIT14  (1<<14)
#define BIT15  (1<<15)
#define BIT16  (1<<16)
#define BIT17  (1<<17)
#define BIT18  (1<<18)
#define BIT19  (1<<19)
#define BIT20  (1<<20)
#define BIT21  (1<<21)
#define BIT22  (1<<22)
#define BIT23  (1<<23)
#define BIT24  (1<<24)
#define BIT25  (1<<25)
#define BIT26  (1<<26)
#define BIT27  (1<<27)
#define BIT28  (1<<28)
#define BIT29  (1<<29)
#define BIT30  (1<<30)   // ..
#define BIT31  (1<<31)   // 0x80000000

/* --------------------------------------------------------------- */
/* Functions                                                       */
/* --------------------------------------------------------------- */
// These functions take a port (GPIO register) number and a bit
// mask -- all those bits that have a 1 in the mask are affected.
// To set a single bit the defines above can be used (e.g., BIT5).

extern int  bitExist(uint port, uint mask);
extern int  bitSet(uint port, uint mask, uint action);
extern int  bitQuery(uint port, uint mask, uint *bits);

extern int  bitEnable(uint port, uint mask, uint action, vector handler);
extern int  bitDisable(uint port, uint mask);

#ifdef TOLLOS_IO
// Bit I/O functions [not for application use]
extern int  bitExistIO(uint port, uint mask);
extern int  bitIntIO(uint port, uint mask, uint action, vector handler);
extern int  bitQueryIO(uint port, uint mask, uint *bits);
extern int  bitSetIO(uint port, uint mask, uint action);
#endif

#endif
