/* --------------------------------------------------------------- */
/* tollosI2C.h -- i2c bus functions for Tollos                     */
/* --------------------------------------------------------------- */
/*                                                                 */
/* Copyright (c) Mike Cowlishaw, 2010-2011.  All rights reserved.  */
/*                                                                 */
/* Permission to use, copy, modify, and/or distribute this         */
/* software for any purpose with or without fee is hereby granted, */
/* provided that the above copyright notice and this permission    */
/* notice appear in all copies, and that notice and the date of    */
/* any modifications be added to the software.                     */
/*                                                                 */
/* This software is provided "as is".  No warranties, whether      */
/* express, implied, or statutory, including, but not limited to,  */
/* implied warranties of merchantability and fitness for a         */
/* particular purpose apply to this software.  The author shall    */
/* not, in any circumstances, be liable for special, incidental,   */
/* or consequential damages, for any reason whatsoever.            */
/*                                                                 */
/* --------------------------------------------------------------- */
/* Generic control functions for i2c bus devices.                  */
/* --------------------------------------------------------------- */


#ifndef TOLLOS_I2C_USED
#define TOLLOS_I2C_USED

#include "tollos.h"      // types etc.

/* Constants */

/* Macros */

// to/from device-encoding (channel in top 16 bits)
#define i2cDevice(channel, addr7bit) ((channel)<<16 | (addr7bit))
#define i2cChannel(device)           ((device)>>16)
#define i2cAddr7Bit(device)          ((device) & 0x7f)
#define i2cAddr10Bit(device)         ((device) & 0x03ff)

/* --------------------------------------------------------------- */
/* Function(s)                                                     */
/* --------------------------------------------------------------- */
// These functions mostly take a 'device address' (i2c channel with
// 7-bit i2c physical address); return value is return code [0=OK]

extern int i2cGetReg(uint device, byte reg, byte *get);
extern int i2cPutReg(uint device, byte reg, byte put);
extern int i2cPutVal(uint device,byte Val);

extern int i2cGetRegs(uint device, byte reg, byte *get, uint len);
extern int i2cPutRegs(uint device, byte reg, byte *put, uint len);

// scanner (debug function/sample code)
extern int i2cScan(uint device1, uint device2);

// low-level O/I
extern int i2cPutGet(uint device, byte *put, uint putlen, byte *get, uint getlen);

#ifdef TOLLOS_IO
// i2C general I/O functions [not for application use]
extern int i2cInitIO(uint channel, uint hz);
extern int i2cIO(uint device, byte *put, uint putlen, byte *get, uint getlen);
#endif

#endif
