/* --------------------------------------------------------------- */
/* tollosLED.c -- on-board LEDs                                    */
/*                                                                 */
/* This is a special case of ""tollosBit"" for simplified access   */
/* to on-board LEDs (if any).  If any are available they  should   */
/* normally be numbered 1, 2, 3, 4, etc.   If only one LED is      */
/* defined then it is recommended that it should be available as   */
/* LED 1 even if also available as other indices (e.g., 0).        */
/* --------------------------------------------------------------- */
/*                                                                 */
/* Copyright (c) Mike Cowlishaw, 2010-2011.  All rights reserved.  */
/*                                                                 */
/* Permission to use, copy, modify, and/or distribute this         */
/* software for any purpose with or without fee is hereby granted, */
/* provided that the above copyright notice and this permission    */
/* notice appear in all copies, and that notice and the date of    */
/* any modifications be added to the software.                     */
/*                                                                 */
/* This software is provided "as is".  No warranties, whether      */
/* express, implied, or statutory, including, but not limited to,  */
/* implied warranties of merchantability and fitness for a         */
/* particular purpose apply to this software.  The author shall    */
/* not, in any circumstances, be liable for special, incidental,   */
/* or consequential damages, for any reason whatsoever.            */
/*                                                                 */
/* --------------------------------------------------------------- */

#define  TOLLOS_IO                 // allow use of I/O functions
#include "tollosLED.h"

/* --------------------------------------------------------------- */
/* ledQuery -- query the state of a LED                            */
/*                                                                 */
/*   num    -- number of the LED (board-defined)                   */
/*                                                                 */
/*   returns the state of the LED (0=Off or 1=On), or -1 if num    */
/*     is not valid                                                */
/* --------------------------------------------------------------- */
int ledQuery(int num) {            // carry out LED action
  sysPause(0);                     // dummy link
  return ledIO(num, LED_QUERY);    // pass on and back
  } // ledQuery

/* --------------------------------------------------------------- */
/* ledSet --  effect an action on a LED                            */
/*                                                                 */
/*   num    -- number of the LED (board-defined)                   */
/*   action -- one of LED_ON, _OFF, _INVERT, _QUERY                */
/*                                                                 */
/*   returns the previous value of the LED (0=Off or 1=Off), or    */
/*     -1 if num or action is invalid                              */
/* --------------------------------------------------------------- */
int ledSet(int num, uint action) { // carry out LED action
  sysPause(0);                     // dummy link
  return ledIO(num, action);       // pass on and back
  } // ledSet

