/* --------------------------------------------------------------- */
/* tollosLED.h -- on-board LEDs                                    */
/* --------------------------------------------------------------- */
/*                                                                 */
/* Copyright (c) Mike Cowlishaw, 2010-2011.  All rights reserved.  */
/*                                                                 */
/* Permission to use, copy, modify, and/or distribute this         */
/* software for any purpose with or without fee is hereby granted, */
/* provided that the above copyright notice and this permission    */
/* notice appear in all copies, and that notice and the date of    */
/* any modifications be added to the software.                     */
/*                                                                 */
/* This software is provided "as is".  No warranties, whether      */
/* express, implied, or statutory, including, but not limited to,  */
/* implied warranties of merchantability and fitness for a         */
/* particular purpose apply to this software.  The author shall    */
/* not, in any circumstances, be liable for special, incidental,   */
/* or consequential damages, for any reason whatsoever.            */
/*                                                                 */
/* --------------------------------------------------------------- */
// Generic LED control functions, usually for some small number of
// user-controlled/test LEDs on the board itself.
//
// Board-dependent code determines which LED to light for a given
// LED number; LED #1 will usually be available -- it is recommended
// that some LED #1 be defined for all boards with user LEDs.


#ifndef TOLLOS_LED_USED
#define TOLLOS_LED_USED

#include "tollos.h"      // types etc.

/* Constants */

// LED actions
#define LED_OFF    0     // force LED off
#define LED_ON     1     // force LED on
#define LED_INVERT 2     // invert LED
#define LED_QUERY  3     // leave LED as-is (query only)

/* --------------------------------------------------------------- */
/* Function(s)                                                     */
/* --------------------------------------------------------------- */
extern int ledQuery(int num);           // return LED state
extern int ledSet(int num, uint action);// carry out LED action
                                        // returns setting before call

// (Could add individual functions for On/Off/Invert later; these
// could be macros, trivially, but would then not be documented as
// easily)


#ifdef TOLLOS_IO
// LED I/O functions [not for application use]
extern int ledIO(int num, uint action); // carry out LED I/O action
#endif

#endif
