/* --------------------------------------------------------------- */
/* tollosSystem.h -- system-dependent functions and definitions    */
/* --------------------------------------------------------------- */
/*                                                                 */
/* Copyright (c) Mike Cowlishaw, 2010-2011.  All rights reserved.  */
/*                                                                 */
/* Permission to use, copy, modify, and/or distribute this         */
/* software for any purpose with or without fee is hereby granted, */
/* provided that the above copyright notice and this permission    */
/* notice appear in all copies, and that notice and the date of    */
/* any modifications be added to the software.                     */
/*                                                                 */
/* This software is provided "as is".  No warranties, whether      */
/* express, implied, or statutory, including, but not limited to,  */
/* implied warranties of merchantability and fitness for a         */
/* particular purpose apply to this software.  The author shall    */
/* not, in any circumstances, be liable for special, incidental,   */
/* or consequential damages, for any reason whatsoever.            */
/*                                                                 */
/* --------------------------------------------------------------- */
/* This defines the interface between the Tollos library and       */
/* system- (processor-) dependent libraries.                       */
/*                                                                 */
/* Functions are provided by the system-dependent library and      */
/* should not normally be used directly by applications            */
/* --------------------------------------------------------------- */
#ifndef TOLLOS_SYSTEM_USED
#define TOLLOS_SYSTEM_USED

#ifdef TOLLOS_IO              // protected functions

/* Constants for sysPower items */
#define SYSTEM_SLEEP          101  // Sleep (idle)
#define SYSTEM_DEEPSLEEP      102  // Sleep (unclocked)
#define SYSTEM_POWERDOWN      103  // Power down (unclocked, slow start)
#define SYSTEM_DEEPPOWERDOWN  104  // Power off until Reset or RTC

/* Constants for sysQuery items */
#define SYSTEM_CLOCK          210  // Reset cause [1=abnormal]
#define SYSTEM_RESET          220  // Reset cause [1=abnormal]
// (items valid for sysSet are always also valid for sysQuery)

/* Constants for sysSet items */
#define SYSTEM_SYSTICK        310  // SysTick interval, ms
#define SYSTEM_WATCHDOG       320  // Watchdog interrupt interval, ms

/* Priority levels */
#define SYSTEM_MAXPRIO          0  // highest priority

#define SYSTEM_USBPRIO          2  // high speed USB device
#define SYSTEM_UARTPRIO         4  // per-byte U[S]ART
#define SYSTEM_BITPRIO         12  // general bits

#define SYSTEM_MINPRIO         15  // lowest priority

/* --------------------------------------------------------------- */
/* Functions                                                       */
/* --------------------------------------------------------------- */
extern void sysFeedDogIO(void);              // throw a chuletilla
extern int  sysInitProcIO(void);             // processor initialize
extern int  sysIRQIO(uint index, flag enable, uint level); // set interrupts
extern void sysPowerIO(uint item);           // enter a powerdown mode
extern int  sysQueryIO(uint item);           // query value of an item
extern int  sysSetIO(uint item, int value);  // set an item

/* --------------------------------------------------------------- */
/* Chip configuration and addresses                                */
/* --------------------------------------------------------------- */

// bytes in ROM and RAM, provided by generic link script (tollos.ld)
extern byte chipVectorSource;      // vectors base initialization
extern byte chipVectorSink;        // end of same, +1
extern char chipVectorStart;       // RAM, start of vectors table
extern char chipVectorEnd;         // end of same, +1
extern char chipDataSource;        // statics initialization
extern char chipDataStart;         // RAM, start of initialized statics
extern char chipDataEnd;           // end of same, +1
extern char chipZeroStart;         // RAM, start of zeroed statics
extern char chipZeroEnd;           // end of same, +1
extern char chipRAMtop;            // top of used RAM, +1
extern char chipRAMend;            // end of RAM, +1
extern char chipROMend;            // end of ROM, +1

// constants in link scripts all look like addresses, so to get their
// values the & address operator must be used

// these must be declared as weak if they might have the value 0
// and might be tested as otherwise GCC will assume they must always
// be non-zero and optimize out dead code accordingly
#define WEAK __attribute__ ((weak))

// constants from chip link script
extern char chipMaxClock;          // maximum clock frequency, Hz
extern char chipVectors;           // vector table size

extern char chipRAMbase;           // base of RAM
extern char chipRAMsize WEAK;      // size of ..
extern char chipROMbase;           // base of ROM
extern char chipROMsize WEAK;      // size of ..
extern char chipSRAM0base;         // base of SRAM0
extern char chipSRAM0size WEAK;    // size of ..
extern char chipSRAM1base;         // base of SRAM1
extern char chipSRAM1size WEAK;    // size of ..

extern char chipCAN WEAK;          // device count
extern char chipDAC WEAK;          // device count
extern char chipEthernet WEAK;     // device count
extern char chipI2C WEAK;          // device count
extern char chipI2S WEAK;          // device count
extern char chipUSB WEAK;          // device count

// constants from the board link script
extern char chipCrystal WEAK;      // crystal/oscillator frequency, Hz
extern char chipOscillator WEAK;   // [optional] 1=oscillator, 0=crystal

#endif
#endif
