/* --------------------------------------------------------------- */
/* tollosUART.c -- UART serial device functions                    */
/* --------------------------------------------------------------- */
/*                                                                 */
/* Copyright (c) Mike Cowlishaw, 2010-2011.  All rights reserved.  */
/*                                                                 */
/* Permission to use, copy, modify, and/or distribute this         */
/* software for any purpose with or without fee is hereby granted, */
/* provided that the above copyright notice and this permission    */
/* notice appear in all copies, and that notice and the date of    */
/* any modifications be added to the software.                     */
/*                                                                 */
/* This software is provided "as is".  No warranties, whether      */
/* express, implied, or statutory, including, but not limited to,  */
/* implied warranties of merchantability and fitness for a         */
/* particular purpose apply to this software.  The author shall    */
/* not, in any circumstances, be liable for special, incidental,   */
/* or consequential damages, for any reason whatsoever.            */
/*                                                                 */
/* --------------------------------------------------------------- */
/* The UART functions provide character I/O over a serial link.    */
/*                                                                 */
/* --------------------------------------------------------------- */
// these are all simple wrapper functions

#define  TOLLOS_IO            // allow use of I/O functions
#include "tollos.h"

/* --------------------------------------------------------------- */
/* uartGetc -- get character from UART device                      */
/*                                                                 */
/*   uart -- ID number of UART to read                             */
/*                                                                 */
/*   returns character read from UART, or -1 if none there or UART */
/*     does not exist                                              */
/*                                                                 */
/* This function does not block.  It returns an int so that errors */
/* are distinct, and will also allow extension.                    */
/* --------------------------------------------------------------- */
int uartGetc(uint uart) {
  return uartGetcIO(uart);
  } // uartGetc

/* --------------------------------------------------------------- */
/* uartInit -- initialize serial UART device                       */
/*                                                                 */
/*   uart -- ID number of UART to initialize                       */
/*   baud -- rate to run uart communications                       */
/*                                                                 */
/*   returns 0 if OK, or -1 if uart does not exist                 */
/* --------------------------------------------------------------- */
int uartInit(uint uart, uint baud) {
  return uartInitIO(uart, baud);
  } // uartInit

/* --------------------------------------------------------------- */
/* uartPutc -- send character to UART device                       */
/*                                                                 */
/*   uart -- ID number of UART to send character to                */
/*   ch   -- character to send                                     */
/*                                                                 */
/*   returns 0 if OK, or -1 if uart does not exist                 */
/*                                                                 */
/* This waits for any previous send to complete.                   */
/* The character, ch, is an int to allow future extension.         */
/* --------------------------------------------------------------- */
int uartPutc(uint uart, int ch) { // send character
  return uartPutcIO(uart, ch);
  } // uartPutc

