/* --------------------------------------------------------------- */
/* tollosVCom.c -- USB Virtual COM port functions                  */
/* --------------------------------------------------------------- */
/*                                                                 */
/* Copyright (c) Mike Cowlishaw, 2010-2011.  All rights reserved.  */
/*                                                                 */
/* Permission to use, copy, modify, and/or distribute this         */
/* software for any purpose with or without fee is hereby granted, */
/* provided that the above copyright notice and this permission    */
/* notice appear in all copies, and that notice and the date of    */
/* any modifications be added to the software.                     */
/*                                                                 */
/* This software is provided "as is".  No warranties, whether      */
/* express, implied, or statutory, including, but not limited to,  */
/* implied warranties of merchantability and fitness for a         */
/* particular purpose apply to this software.  The author shall    */
/* not, in any circumstances, be liable for special, incidental,   */
/* or consequential damages, for any reason whatsoever.            */
/*                                                                 */
/* --------------------------------------------------------------- */
/* The vcom functions provide character I/O over a USB Virtual     */
/* COM port.                                                       */
/*                                                                 */
/* It is assumed that there is a primary, or only one, USB link    */
/* so these functions do not specify a device number.              */
/* --------------------------------------------------------------- */
// these are all simple wrapper/pass-through functions

#define  TOLLOS_IO            // allow use of I/O functions
#include "tollos.h"

/* --------------------------------------------------------------- */
/* vcomGetc -- get character from vcom device                      */
/*                                                                 */
/*   returns character read from vcom, or -1 if none there or vcom */
/*     has not been initialized                                    */
/*                                                                 */
/* This function does not block.  It returns an int so that errors */
/* are distinct, and will also allow extension.                    */
/* --------------------------------------------------------------- */
int vcomGetc(void) {
  return vcomGetcIO();
  } // vcomGetc

/* --------------------------------------------------------------- */
/* vcomInit -- initialize serial vcom device                       */
/*                                                                 */
/*   returns 0 if OK, negative if interrupt already in use         */
/*                                                                 */
/* This does not switch a software connection as this is           */
/* device-dependent (port, pin, and direction), so the caller      */
/* should use bitSet to make the connection before calling this.   */
/* --------------------------------------------------------------- */
int vcomInit(void) {
  return vcomInitIO();
  } // vcomInit

/* --------------------------------------------------------------- */
/* vcomPutc -- send character to vcom device                       */
/*                                                                 */
/*   ch -- character to send                                       */
/*                                                                 */
/*   returns 0 if OK, or -1 if vcom has not been initialized, or   */
/*   -2 if there is a data overrun (bytes have been queued faster  */
/*   than they could be sent to the host)                          */
/*                                                                 */
/* This function does not block.                                   */
/*                                                                 */
/* Note that this must not be called from an interrupt handler     */
/* that has a higher priority than USB.                            */
/* --------------------------------------------------------------- */
int vcomPutc(int ch) {
  return vcomPutcIO(ch);
  } // vcomPutc

/* --------------------------------------------------------------- */
/* vcomStop -- stop the vcom device                                */
/*                                                                 */
/* This does not switch a software connection because this is      */
/* device-dependent (port, pin, and direction), so the caller      */
/* should use bitSet to make the connection an input after         */
/* calling this.                                                   */
/*                                                                 */
/* vcomStop has no effect if vcom has not been initialized.        */
/* --------------------------------------------------------------- */
void vcomStop(void) {
  vcomStopIO();
  } // vcomStop

